pypaginate.domain
=================

.. py:module:: pypaginate.domain

.. autoapi-nested-parse::

   Domain layer — pure definitions with zero external dependencies (except Pydantic).



Submodules
----------

.. toctree::
   :maxdepth: 1

   /api/pypaginate/domain/enums/index
   /api/pypaginate/domain/exceptions/index
   /api/pypaginate/domain/fast_pages/index
   /api/pypaginate/domain/pages/index
   /api/pypaginate/domain/params/index
   /api/pypaginate/domain/protocols/index
   /api/pypaginate/domain/specs/index


